%define realname qwt
%define major    6

Name:           libqwt
Version:        6.1.5
Release:        %mkrel 3
Summary:        2D plotting widget extension to the Qt GUI
License:        Qwt License 1.0
Group:          System/Libraries
Url:            https://qwt.sourceforge.io/
Source:         http://downloads.sourceforge.net/%{realname}/%{realname}-%{version}.tar.bz2
## upstream patches

## upstreamable patches
# fix pkgconfig support
Patch50:        qwt-6.1.1-pkgconfig.patch
# use QT_INSTALL_ paths instead of custom prefix
Patch51:        qwt-6.1.5-qt_install_paths.patch
# parallel-installable qt5 version
Patch52:        qwt-qt5.patch
#
Patch53:        qwt-6.1.3-no_rpath.patch

### Qt4 BuildRequires
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtDesigner)
BuildRequires:  pkgconfig(QtSvg)

### Qt5 BuildRequires
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
Qwt is an extension to the Qt GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

#------------------------------------------------------------------------------
### Qt4 ###

%define libname %mklibname %realname %{major}

%package -n     %{libname}
Summary:        2D plotting widget extension to the Qt4 GUI
Group:          System/Libraries

%description -n %{libname}
Qwt is an extension to the Qt4 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname}
%doc CHANGES* README
%license COPYING
%{_qt4_libdir}/libqwt.so.%{major}{,.*}
%{_qt4_libdir}/libqwtmathml.so.%{major}{,.*}

#------------------------------------------------------------------------------

%define libnamedev %mklibname qwt -d

%package -n     %{libnamedev}
Summary:        Development tools for programs which uses Qt4 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname} = %{version}
Provides:       libqwt-devel = %{version}-%{release}
Provides:       libqwtmathml-devel = %{version}-%{release}
Conflicts:      %{_lib}qwt5-devel

%description -n %{libnamedev}
The %{libnamedev} package contains the header files and static libraries
necessary for developing programs using the Qt4 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt package.

%files -n %{libnamedev}
%doc COPYING
%doc examples
%docdir %{_qt4_docdir}/html/
%{_qt4_docdir}/html/qwt/
%{_qt4_docdir}/html/man/
%{_qt4_includedir}/qwt/
%{_qt4_libdir}/libqwt.so
%{_qt4_libdir}/libqwtmathml.so
%{_qt4_libdir}/pkgconfig/qwt.pc
%{_qt4_libdir}/pkgconfig/qwtmathml.pc
%{_qt4_datadir}/mkspecs/*

### End Qt4 ###

#------------------------------------------------------------------------------
#------------------------------------------------------------------------------

### Qt5 ###

%define libname_qt5 %mklibname %realname-qt5_ %{major}

%package -n     %{libname_qt5}
Summary:        2D plotting widget extension to the Qt5 GUI
Group:          System/Libraries

%description -n %{libname_qt5}
Qwt is an extension to the Qt5 GUI library from Troll Tech AS.
The Qwt library contains widgets and components which are
primarily useful for technical and scientifical purposes.
It includes a 2-D plotting widget, different kinds of sliders,
and much more.

This package provides the runtime library.

%files -n %{libname_qt5}
%doc CHANGES* README
%license COPYING
%{_qt5_libdir}/libqwt-qt5.so.%{major}{,.*}
%{_qt5_libdir}/libqwtmathml-qt5.so.%{major}{,.*}
%{_qt5_plugindir}/designer/libqwt_designer_plugin.so

#------------------------------------------------------------------------------

%define libnamedev_qt5 %mklibname qwt-qt5 -d

%package -n     %{libnamedev_qt5}
Summary:        Development tools for programs which uses Qt5 Qwt Widget set
Group:          System/Libraries
Requires:       %{libname_qt5} = %{version}
Provides:       libqwt-qt5-devel = %{version}-%{release}
Provides:       libqwtmathml-qt5-devel = %{version}-%{release}

%description -n %{libnamedev_qt5}
The %{libnamedev_qt5} package contains the header files and static libraries
necessary for developing programs using the Qt5 Qwt Widget set.

If you want to develop programs which will use this set of widgets,
you should install this package. You need also to install the libqwt-qt5 package.

%files -n %{libnamedev_qt5}
%doc COPYING
%doc examples
%docdir %{_qt5_docdir}/html/
%{_qt5_docdir}/html/qwt/
%{_qt5_includedir}/qwt/
%{_qt5_libdir}/libqwt-qt5.so
%{_qt5_libdir}/libqwtmathml-qt5.so
%{_qt5_libdir}/pkgconfig/Qt5Qwt6.pc
%{_qt5_libdir}/pkgconfig/qwtmathml-qt5.pc
%{_qt5_archdatadir}/mkspecs/*
%{_mandir}/man3/*

### End Qt5 ###
#------------------------------------------------------------------------------

%prep
%setup -q -n %{realname}-%{version}
%autopatch -p1

%build
### Qt5 Build ###
mkdir qt5 && pushd qt5
%qmake_qt5 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

### Qt4 Build ###
mkdir qt4 && pushd qt4
%qmake_qt4 QWT_CONFIG+=QwtPkgConfig ..
%make_build
popd

%install
### Qt5 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt5

mv %{buildroot}%{_qt5_docdir}/html/html %{buildroot}%{_qt5_docdir}/html/qwt
mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{_qt5_docdir}/html/man/man3 %{buildroot}%{_mandir}/

### Qt4 Install ###
%make_install INSTALL_ROOT=%{buildroot} -C qt4

mv %{buildroot}%{_qt4_docdir}/html/html %{buildroot}%{_qt4_docdir}/html/qwt


%changelog
* Fri Dec 18 2020 daviddavid <daviddavid> 6.1.5-3.mga8
+ Revision: 1660547
- rebuild for missing pkgs

* Thu Dec 17 2020 umeabot <umeabot> 6.1.5-2.mga8
+ Revision: 1658953
- Rebuild for new Qt5

* Tue Jul 14 2020 daviddavid <daviddavid> 6.1.5-1.mga8
+ Revision: 1605857
- new version: 6.1.5 (compatibility to Qt 5.15)

* Wed Feb 19 2020 umeabot <umeabot> 6.1.4-2.mga8
+ Revision: 1542751
- Mageia 8 Mass Rebuild

* Tue Jan 07 2020 daviddavid <daviddavid> 6.1.4-1.mga8
+ Revision: 1477035
- new version: 6.1.4

* Sat Jul 27 2019 daviddavid <daviddavid> 6.1.3-4.mga8
+ Revision: 1424478
- rebuild for new Qt5 headers path

* Sun Mar 31 2019 umeabot <umeabot> 6.1.3-3.mga7
+ Revision: 1383200
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 6.1.3-2.mga7
+ Revision: 1299113
- Mageia 7 Mass Rebuild

* Wed Apr 18 2018 daviddavid <daviddavid> 6.1.3-1.mga7
+ Revision: 1219771
- new version: 6.1.3
- add Qt5 support

* Sat Feb 06 2016 umeabot <umeabot> 6.0.1-9.mga6
+ Revision: 941594
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 6.0.1-8.mga5
+ Revision: 749041
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.0.1-7.mga5
+ Revision: 681739
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 6.0.1-6.mga4
+ Revision: 507316
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 6.0.1-5.mga3
+ Revision: 358045
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 18 2012 zezinho <zezinho> 6.0.1-4.mga3
+ Revision: 319481
- add conflicts with libqwt5

* Sun Nov 18 2012 zezinho <zezinho> 6.0.1-3.mga3
+ Revision: 319446
- conflict devel package and remove bad obsoletes

* Sat Nov 17 2012 zezinho <zezinho> 6.0.1-2.mga3
+ Revision: 319237
- obsoletes qwt5

* Sat Nov 17 2012 zezinho <zezinho> 6.0.1-1.mga3
+ Revision: 319010
- fix build
- update patch

* Fri Nov 16 2012 zezinho <zezinho> 5.2.2-3.mga3
+ Revision: 318996
- spec cleanup

* Tue Dec 27 2011 dmorgan <dmorgan> 5.2.2-2.mga2
+ Revision: 187989
- Rebuild against new qt4 and new include path

* Mon Dec 12 2011 mikala <mikala> 5.2.2-1.mga2
+ Revision: 181023
- Update tarball to 5.2.2
- sync patch0 with fedora's one
- drop patch1
- change spec layout
- fix description
- remove %%clean & %%defattr()

* Fri Apr 01 2011 ahmad <ahmad> 5.2.1-3.mga1
+ Revision: 79417
- drop old/unneeded scriptlets
- imported package libqwt


* Sat Feb 05 2011 Funda Wang <fwang@mandriva.org> 5.2.1-2mdv2011.0
+ Revision: 636050
- tighten BR

* Mon Aug 23 2010 Yuri Myasoedov <omerta13@mandriva.org> 5.2.1-1mdv2011.0
+ Revision: 572091
- New version 5.2.1

* Fri May 01 2009 Funda Wang <fwang@mandriva.org> 5.2.0-1mdv2010.0
+ Revision: 369350
- New version 5.2.0

* Fri Mar 13 2009 Funda Wang <fwang@mandriva.org> 5.1.1-1mdv2009.1
+ Revision: 354460
- rediff patch

* Tue Aug 05 2008 Funda Wang <fwang@mandriva.org> 5.1.1-1mdv2009.0
+ Revision: 263932
- New version 5.1.1

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 15 2008 Funda Wang <fwang@mandriva.org> 5.1.0-1mdv2009.0
+ Revision: 207499
- New version 5.1.0

* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 5.0.2-1mdv2008.1
+ Revision: 140928
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Jul 21 2007 Funda Wang <fwang@mandriva.org> 5.0.2-1mdv2008.0
+ Revision: 54251
- New version
- renew file list
- Build qt4 version

* Mon Apr 23 2007 Lenny Cartier <lenny@mandriva.org> 5.0.1-1mdv2008.0
+ Revision: 17323
- Update to 5.0.1


* Tue Jan 23 2007 Lenny Cartier <lenny@mandriva.com> 5.0.0-1mdv2007.0
+ Revision: 112574
- Updated to 5.0.0

* Fri Aug 11 2006 Gaëtan Lehmann <glehmann@mandriva.org> 4.2.0-6mdv2007.0
+ Revision: 55477
- rebuild
- Import libqwt

* Mon Dec 12 2005 Helio Chissini de Castro <helio@mandriva.com> 4.2.0-5mdk
- Move designer plugins for proper place in lib or lib64

* Wed Oct 05 2005 Lenny Cartier <lenny@mandriva.com> 4.2.0-4mdk
- rebuild

* Wed Jul 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 4.2.0-3mdk
- build on x86_64
- fix buildrequires

* Sat Jun 25 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 4.2.0-2mdk
- use mkrel
- fix doc path warning

* Wed Mar 02 2005 Olivier Lahaye <olivier.lahaye1@free.Fr> 1mdk
- port spec to Mandrake 10.1

* Fri Feb 11 2005 Vitaly Lipatov <lav@altlinux.ru> 4.2.0-alt2
- move libraries to /usr/lib64, fix .so placement

* Fri Dec 03 2004 Vitaly Lipatov <lav@altlinux.ru> 4.2.0-alt1
- first build for ALT Linux Sisyphus

